import typer
from dotenv import load_dotenv
from .helpers import get_authenticated_service, classify_and_delete


load_dotenv()
app = typer.Typer()


@app.command()
def comments(video_id: str):
    """ Get spam comments and delete them"""
    youtube = get_authenticated_service()
    res = youtube.commentThreads().list(
        part="snippet",
        videoId=video_id
    ).execute()
    d = {}
    for x in res['items']:
        comm = x['snippet']['topLevelComment']
        dsp = comm['snippet']['textDisplay']
        id = comm['id']
        l = d.get(dsp, [])
        l.append(id)
        d[dsp] = l

    classify_and_delete(list(d.keys()), d, youtube)


@app.command()
def login():
    """
    login
    """

    get_authenticated_service(use_ex=False)



    




import os
import pickle
from google_auth_oauthlib.flow import InstalledAppFlow
from googleapiclient.discovery import build
import cohere


co = cohere.Client(os.getenv('cohere_key'))
CLIENT_SECRETS_FILE = 'client_secret.json'
SCOPES = ['https://www.googleapis.com/auth/youtube.force-ssl']
API_SERVICE_NAME = 'youtube'
API_VERSION = 'v3'

def get_authenticated_service(use_ex=True):
    if (use_ex):
        try:
            credentials = pickle.load(open('cred', 'rb'))
            return build(API_SERVICE_NAME, API_VERSION, credentials = credentials)
        except:
            pass

    flow = InstalledAppFlow.from_client_secrets_file(CLIENT_SECRETS_FILE, SCOPES)
    credentials = flow.run_local_server(host='localhost',
    port=8080, 
    authorization_prompt_message='Please visit this URL: {url}', 
    success_message='The auth flow is complete; you may close this window.',
    open_browser=True)
    pickle.dump(credentials, open('cred', 'wb'))

    return build(API_SERVICE_NAME, API_VERSION, credentials = credentials)


def classify_and_delete(inp, d, youtube):
    classifications = co.classify(
        model=os.getenv('model'),
        outputIndicator='this is:',
        inputs=inp)

    cls = classifications.classifications
    out = set()
    spams = []

    for c in cls:
        if(c.prediction == 'spam'):
            out.update(d[c.input])
            spams.append(c.input)

    print("Spam Comments are:" + spams)
    delete_comments(out, youtube)

      
def delete_comments(ids, youtube):
    for id in ids:
        youtube.comments().delete(id=id).execute()


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['retracto']

package_data = \
{'': ['*']}

install_requires = \
['cohere>=2.4.2,<3.0.0',
 'google-api-python-client>=2.62.0,<3.0.0',
 'google-auth-oauthlib>=0.5.3,<0.6.0',
 'python-dotenv>=0.21.0,<0.22.0',
 'requests>=2.28.1,<3.0.0',
 'typer[all]>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['retracto = retracto.app:app']}

setup_kwargs = {
    'name': 'retracto',
    'version': '0.1.0',
    'description': '',
    'long_description': 'None',
    'author': 'Amit Krishna A',
    'author_email': 'amit.ananthkumar@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
